@@ -23,6 +23,11 @@ gint btctl_controller_impl_scan_for_service(BtctlController *bc, const gchar *bd
 int btctl_controller_impl_get_signal_strength (BtctlController *bc, 		const gchar *bdstr, GError **err);
 void btctl_controller_impl_request_name (BtctlController *bc, const gchar *bdaddr);
 
+gboolean btctl_controller_impl_get_discoverable(BtctlController *bc, GError **err);
+void btctl_controller_impl_set_discoverable(BtctlController *bc, gboolean discoverable, GError **err);
+
+void btctl_controller_impl_set_interface(BtctlController *bc, const char *hci_device, GError **err);
+
 void btctl_controller_impl_init_source(BtctlController *bc);
 
 
